
S = ['#FF0000', '#FFFF00', '#D02090', '#00FF00', '#FFD700', '#696969']

TM = ['#A0A0A4']
GPCR = ['#FBE5D6', '#F4B183', '#C55A11', '#843C0C', '#F6B285']
Ionchannel = ['#E2F0D9', '#A9D18E', '#548235', '#385723', '#ABD28F']
Transporter = ['#DEEBF7', '#9DC3E6', '#2E75B6', '#1F4E79', '#9DC2E6']

DIA = ['#DCDCDB']
DDA = ['#B78BBD']
Virtual = ['#C6D0E0']
Hybrid = ['#F6E0D2', '#EB634B']

DarkGreyBlue = '#516E82'
LightGreyBlue = '#81A8BF'

BrickRed = '#A33931'
LightBrickRed = '#C27E7E'
